@@ -18,7 +18,7 @@
 /* Originally written by David Keppel, pardo@cs.washington.edu.
    Heavily modified by David MacKenzie, djm@gnu.ai.mit.edu.  */
 
-static const char *version_string = "GNU time version 1.5";
+static const char *version_string = "GNU time version 1.6";
 
 #include <stdio.h>
 #include <sys/types.h>
@@ -42,6 +42,9 @@ static void usage PARAMS((FILE *, int));
 /* A Pointer to a signal handler.  */
 typedef RETSIGTYPE (*sighand_t) ();
 
+/* msec = milliseconds = 1/1,000 (1*10e-3) second.
+   usec = microseconds = 1/1,000,000 (1*10e-6) second.  */
+
 /* The number of milliseconds in one `tick' used by the `rusage' structure.
 
    At least one Unix man page has an error, as it reports
@@ -242,7 +245,7 @@ ptok (pages)
    % == a literal `%'
    C == command name and arguments
 *  D == average unshared data size in K (ru_idrss+ru_isrss)
-*  E == elapsed real (wall clock) time in [hour:]min:sec.usec
+*  E == elapsed real (wall clock) time in [hour:]min:sec
 *  F == major page faults (required physical I/O) (ru_majflt)
 *  I == file system inputs (ru_inblock)
 *  K == average total mem usage (ru_idrss+ru_isrss+ru_ixrss)
@@ -250,13 +253,13 @@ ptok (pages)
 *  O == file system outputs (ru_oublock)
 *  P == percent of CPU this job got (total cpu time / elapsed time)
 *  R == minor page faults (reclaims; no physical I/O involved) (ru_minflt)
-*  S == system (kernel) time (seconds:usec) (ru_stime)
-*  U == user time (seconds:usec) (ru_utime)
+*  S == system (kernel) time (seconds) (ru_stime)
+*  U == user time (seconds) (ru_utime)
 *  W == times swapped out (ru_nswap)
 *  X == average amount of shared text in K (ru_ixrss)
    Z == page size
 *  c == involuntary context switches (ru_nivcsw)
-   e == elapsed real time in sec.usec
+   e == elapsed real time in seconds
 *  k == signals delivered (ru_nsignals)
    p == average unshared stack size in K (ru_isrss)
 *  r == socket messages received (ru_msgrcv)
@@ -272,7 +275,7 @@ ptok (pages)
    FP is the stream to print to.
    FMT is the format string, interpreted as described above.
    COMMAND is the command and args that are being summarized.
-   RESP is information on the command.  */
+   RESP is resource information on the command.  */
 
 static void
 summarize (fp, fmt, command, resp)
@@ -317,13 +320,13 @@ summarize (fp, fmt, command, resp)
 		       ptok ((UL) resp->ru.ru_isrss) / MSEC_TO_TICKS (v));
 	      break;
 	    case 'E':		/* Elapsed real (wall clock) time.  */
-	      if (resp->elapsed.tv_sec >= 3600)	/* One hour.  */
+	      if (resp->elapsed.tv_sec >= 3600)	/* One hour -> h:m:s.  */
 		fprintf (fp, "%ld:%02ld:%02ld",
 			 resp->elapsed.tv_sec / 3600,
 			 (resp->elapsed.tv_sec % 3600) / 60,
 			 resp->elapsed.tv_sec % 60);
 	      else
-		fprintf (fp, "%ld:%02ld.%02ld",
+		fprintf (fp, "%ld:%02ld.%02ld",	/* -> m:s.  */
 			 resp->elapsed.tv_sec / 60,
 			 resp->elapsed.tv_sec % 60,
 			 resp->elapsed.tv_usec / 10000);
@@ -559,7 +562,9 @@ run_command (cmd, resp)
     error (1, errno, "cannot fork");
   else if (pid == 0)
     {				/* If child.  */
-      execvp (cmd[0], (char *const *) cmd);
+      /* Don't cast execvp arguments; that causes errors on some systems,
+	 versus merely warnings if the cast is left off.  */
+      execvp (cmd[0], cmd);
       error (0, errno, "cannot run %s", cmd[0]);
       _exit (errno == ENOENT ? 127 : 126);
     }
